Binscatter provides a flexible, yet parsimonious way of visualizing and summarizing large data sets in regression
settings, and has been a popular methodology in applied microeconomics and other social sciences. The binsreg package provides tools for
statistical analysis using the binscatter methods developed in
Cattaneo, Crump, Farrell and Feng (2019a).
binsreg implements binscatter estimation with robust inference and plots, including
curve estimation, pointwise confidence intervals and uniform confidence band.
binsregtest implements hypothesis testing procedures for parametric specification
of and nonparametric shape restrictions on the unknown regression function.
binsregselect implements data-driven number of bins selectors for binscatter
implementation using either quantile-spaced or evenly-spaced binning/partitioning.
All the commands allow for covariate adjustment, smoothness restrictions, and clustering,
among other features.
The companion software article, Cattaneo, Crump, Farrell and Feng (2019b), provides further implementation details and empirical illustration. For related Stata and R packages useful for nonparametric data analysis and statistical inference, visit https://sites.google.com/site/nppackages.
Cattaneo, M. D., R. K. Crump, M. H. Farrell, and Y. Feng. 2019a: On Binscatter. Working Paper.
Cattaneo, M. D., R. K. Crump, M. H. Farrell, and Y. Feng. 2019b: Binscatter Regressions. Working Paper.